@@ -21,6 +21,7 @@ class gram(Datasource):
         name : `str`
             A name for the datasource.
     """
+
     def __init__(self, items_datasource, grams=[(0,)], name=None):
         name = self._format_name(name, [items_datasource, grams])
         super().__init__(name, self.process,
@@ -35,6 +36,6 @@ def gram_tokens(items, grams=[(0,)]):
     for i in range(len(items)):
         for gram in grams:
             if gram == (0,):
-                yield items[i]
+                yield (items[i], )
             elif len(items) > i + max(gram):
                 yield tuple(items[i + offset] for offset in gram)
