@@ -1,10 +1,16 @@
+from revscoring.dependencies import DependentSet
+
 from . import chars, edit_tokens, parsed, tokenized
 
+prefix = "wikitext.revision"
+
+
+class BaseRevision(DependentSet):
 
-class Revision(parsed.Revision, chars.Revision, tokenized.Revision):
     def __init__(self, name, revision_datasources):
-        # Initializes all of the Revision datasources
-        super().__init__(name, revision_datasources)
+        super().__init__(name)
+        self.datasources = revision_datasources
+
         if hasattr(self.datasources, "parent"):
             self.parent = Revision(
                 name + ".parent",
@@ -26,5 +32,17 @@ class Revision(parsed.Revision, chars.Revision, tokenized.Revision):
             """
 
 
-class Diff(chars.Diff, edit_tokens.Diff, tokenized.Diff):
+class Revision(parsed.Revision, chars.Revision, tokenized.Revision,
+               BaseRevision):
+    pass
+
+
+class BaseDiff(DependentSet):
+
+    def __init__(self, name, diff_datasources, *args, **kwargs):
+        super().__init__(name)
+        self.datasources = diff_datasources
+
+
+class Diff(chars.Diff, edit_tokens.Diff, tokenized.Diff, BaseDiff):
     pass
