@@ -7,7 +7,9 @@
     Usage:
         score (-h | --help)
         score <model-file> --host=<uri> [<rev_id>...]
-              [--rev-ids=<path>] [--cache=<json>] [--caches=<json>]
+              [--rev-docs=<path>] [--output=<path>]
+              [--cache=<json>] [--caches=<json>]
+              [--score-field=<key>]
               [--batch-size=<num>] [--io-workers=<num>] [--cpu-workers=<num>]
               [--debug] [--verbose]
 
@@ -17,20 +19,25 @@
         --host=<url>        The url pointing to a MediaWiki API to use for
                             extracting features
         <rev_id>            A revision identifier to score.
-        --rev-ids=<path>    The path to a file containing revision identifiers
-                            to score (expects a column called 'rev_id').  If
-                            any <rev_id> are provided, this argument is
-                            ignored. [default: <stdin>]
+        --rev-docs=<path>   The path to a file containing json blobs with a
+                            "rev_id" field to score.  If any <rev_id> are
+                            provided, this argument is ignored.
+                            [default: <stdin>]
+        --output=<path>     Path to a file to write rev_docs with score data to
+                            [default: <stdout>]
         --cache=<json>      A JSON blob of cache values to use during
                             extraction for every call.
         --caches=<json>     A JSON blob of rev_id-->cache value pairs to use
                             during extraction
+        --score-field=<key> The field name that the score will be inserted into
+                            [default: score]
         --batch-size=<num>  The size of the revisions to batch when requesting
                             data from the API [default: 50]
         --io-workers=<num>  The number of worker processes to use for
                             requesting data from the API [default: <auto>]
         --cpu-workers=<num>  The number of worker processes to use for
                              extraction and scoring [default: <cpu-count>]
+
         --debug             Print debug logging
         --verbose           Print feature extraction debug logging
 """
@@ -41,11 +48,12 @@ from multiprocessing import cpu_count
 
 import docopt
 import mwapi
-import mysqltsv
+from more_itertools import chunked
 
 from ..extractors import api
 from ..score_processor import ScoreProcessor
 from ..scoring import Model, models
+from .util import read_observations, dump_observation
 
 
 def main(argv=None):
@@ -66,14 +74,17 @@ def main(argv=None):
     extractor = api.Extractor(session)
 
     if len(args['<rev_id>']) > 0:
-        rev_ids = (int(rev_id) for rev_id in args['<rev_id>'])
+        rev_docs = ({'rev_id': int(rev_id)} for rev_id in args['<rev_id>'])
     else:
-        if args['--rev-ids'] == "<stdin>":
-            rev_ids_f = sys.stdin
+        if args['--rev-docs'] == "<stdin>":
+            rev_docs = read_observations(sys.stdin)
         else:
-            rev_ids_f = open(args['--rev-ids'])
+            rev_docs = read_observations(open(args['--rev-ids']))
 
-        rev_ids = (int(row.rev_id) for row in mysqltsv.read(rev_ids_f))
+    if args['--output'] == "<stdout>":
+        output = sys.stdout
+    else:
+        output = open(args['--output'], 'w')
 
     if args['--caches'] is not None:
         caches = json.loads(args['--caches'])
@@ -85,6 +96,8 @@ def main(argv=None):
     else:
         cache = None
 
+    score_field = args['--score-field']
+
     batch_size = int(args['--batch-size'])
 
     if args['--cpu-workers'] == "<cpu-count>":
@@ -105,23 +118,28 @@ def main(argv=None):
         scoring_model, extractor, batch_size=batch_size,
         cpu_workers=cpu_workers, io_workers=io_workers)
 
-    run(score_processor, rev_ids, caches, cache, debug, verbose)
+    run(score_processor, rev_docs, output, caches, cache, score_field, io_workers, debug, verbose)
 
 
-def run(score_processor, rev_ids, caches, cache, debug, verbose):
+def run(score_processor, rev_docs, output, caches, cache, score_field, io_workers, debug, verbose):
 
-    rev_scores = score_processor.score(rev_ids, caches, cache)
+    for rev_doc_chunk in chunked(rev_docs, 50 * score_processor.io_workers):
+        rev_doc_chunk = list(rev_doc_chunk)
+        rev_ids = [r['rev_id'] for r in rev_doc_chunk]
+        rev_scores = score_processor.score(rev_ids, caches, cache)
 
-    for rev_id, score in rev_scores:
-        print("\t".join([str(rev_id), json.dumps(score)]))
-        if verbose:
-            if 'error' in score:
-                if "NotFound" in score['error']['type']:
-                    sys.stderr.write("?")
-                elif "Deleted" in score['error']['type']:
-                    sys.stderr.write("d")
+        for rev_doc, (rev_id, score) in zip(rev_doc_chunk, rev_scores):
+            rev_doc[score_field] = score
+            dump_observation(rev_doc, output)
+
+            if verbose:
+                if 'error' in score:
+                    if "NotFound" in score['error']['type']:
+                        sys.stderr.write("?")
+                    elif "Deleted" in score['error']['type']:
+                        sys.stderr.write("d")
+                    else:
+                        sys.stderr.write("e")
                 else:
-                    sys.stderr.write("e")
-            else:
-                sys.stderr.write(".")
-            sys.stderr.flush()
+                    sys.stderr.write(".")
+                sys.stderr.flush()
